pub struct HookConstruction<CurrentStores: StoresList, EntireStores: StoresList> { /* private fields */ }Expand description
This is the consecuit or cc object in your hook function.
You can use it to call other hooks.
You must return it at the end of your hook function. (See the doc at crate on how to write hooks).
Implementations
Sourceimpl<ThisStore, RestStores, EntireStores> HookConstruction<StoreCons<ThisStore, RestStores>, EntireStores>where
ThisStore: StoresList,
RestStores: StoresList,
EntireStores: StoresList,
impl<ThisStore, RestStores, EntireStores> HookConstruction<StoreCons<ThisStore, RestStores>, EntireStores>where
ThisStore: StoresList,
RestStores: StoresList,
EntireStores: StoresList,
Sourcepub fn hook<Arg, Out, Ret>(
self,
hook_func: fn(HookBuilder, Arg) -> Ret,
hook_arg: Arg,
) -> (HookConstruction<RestStores, EntireStores>, Out)where
Ret: HookReturn<Out, StoresList = ThisStore>,
pub fn hook<Arg, Out, Ret>(
self,
hook_func: fn(HookBuilder, Arg) -> Ret,
hook_arg: Arg,
) -> (HookConstruction<RestStores, EntireStores>, Out)where
Ret: HookReturn<Out, StoresList = ThisStore>,
Use the given hook, with the given arg.
Consumes self. Returns a tuple of (cc, <return value of hook>).
You can use the returned cc to call more hooks.
See the docs at crate for more info on how to write and use hooks.